const mongoose = require('mongoose');
const Schema = mongoose.Schema;
const timestamps = require('mongoose-timestamps');

const BidSchema = new Schema({
  bidder: {
    type: Schema.ObjectId,
    ref: 'Buyer'
  },
  box: [{
    type: Schema.ObjectId,
    ref: 'Box'
  }],
  negotiation: {
    type: Schema.ObjectId,
    ref: 'Negotiation'
  },
  status: {
    type: String,
    default: 'Pending',
    enum: ['Pending', 'Approved', 'Disapproved', 'Expired']
  },
  bidPrice: Number,
  bidTerms: {
    type: String,
    enum: ['Cash', '30 Days', '60 Days', '90 Days', '120 Days']
  },
  bidTimeout: {
    type: Date,
    default: Date.now
  },
  public: {
    type: Boolean,
    default: true
  },
  isAnonymous: {
    type: Boolean,
    default: false
  },
  notified: {
    type: Boolean,
    default: false
  }
});

BidSchema.plugin(timestamps);

BidSchema.pre('save', function (next) {
  const bid = this;
  
  if (bid.isModified('bidTimeout')) {
    bid.bidTimeout = new Date(Date.now() + Number(bid.bidTimeout));
  }
  
  bid.bidPrice = parseFloat(bid.bidPrice);

  return next();
});

module.exports = mongoose.model('Bid', BidSchema);
