const mongoose = require('mongoose');
const Schema = mongoose.Schema;
const timestamps = require('mongoose-timestamps');

const BoxTypeSchema = new Schema({
  producer: { // Producer
    type: Schema.ObjectId,
    ref: 'Producer'
  },
  typeOfSale: { // Type of Sale
    type: Schema.ObjectId,
    ref: 'SaleType'
  },
  origin: String, // Origin
  category: String, // Category
  minItemSize: Number, // Min Item Size
  allowSupplierUpload: {
    type: Boolean,
    default: true
  }, // Upload by Supplier
  validation: {
    type: Boolean,
    default: false
  }, // Validation
  hasLotId: {
    type: Boolean,
    default: false
  }, // Has Lot #
  allowComments: {
    type: Boolean,
    default: false
  }, // Allow Comments
  allowAttachment: {
    type: Boolean,
    default: false
  }, // Allow Attachment
  allowPicture: {
    type: Boolean,
    default: false
  }, // Allow Picture
  associateSupplier: { // Allow Supplier Id
    type: String,
    enum: [null, 'auto', 'manual'],
    default: 'auto'
  },
  shouldGroup: {
    type: Boolean,
    default: true
  }, // Grouped
  associateEvent: { // Event Associate
    type: String,
    enum: [null, 'auto', 'manual'],
    default: 'auto'
  },
  hasCycle: {
    type: Boolean,
    default: false
  }, // Has Cycle
  allowBidderTerms: {
    type: Boolean,
    default: true
  }, // Allow Bidder Terms
  allowSupplierTerms: {
    type: Boolean,
    default: false
  }, // Allow Supplier Terms
  article: String, // Article
  onlyPpc: { // Only $/Ct
    type: Boolean,
    default: false
  },
  withdrawAnytime: {
    type: Boolean,
    default: false
  }, // Withdraw Anytime
  allowHennigSeal: {
    type: Boolean,
    default: false
  }, // Allow Hennig Seal
  buyNowOption: {
    type: Boolean,
    default: false
  }, // Allow Hennig Seal
  relevantSearch: {
    type: String,
    enum: [null, 'auto', 'allow'],
    default: 'auto'
  },
  breakdown: [{ // Breakdown
    type: String
  }]
});

BoxTypeSchema.plugin(timestamps);

module.exports = mongoose.model('BoxType', BoxTypeSchema);