const mongoose = require("mongoose");
const Schema = mongoose.Schema;
const timestamps = require("mongoose-timestamps");

const EventSchema = new Schema({
  producers: [
    {
      // Allowed producers
      type: Schema.ObjectId,
      ref: "Producer"
    }
  ],
  typeOfSales: [
    {
      // Type of Sales
      type: Schema.ObjectId,
      ref: "SaleType"
    }
  ],
  notified: {
    type: Boolean,
    default: false
  },
  liveBoxes: {
    // Show only live boxes
    type: Boolean,
    default: false
  },
  withdrawDate: Date,
  limitBoxTypes: {
    type: Boolean,
    default: false
  },
  hasCatalog: {
    type: Boolean,
    default: false
  },
  eventNumber: Number,
  name: String,
  location: String,
  description: String,
  status: {
    type: String,
    enum: ["Active", "Inactive"],
    default: "Inactive"
  },
  published: {
    type: Boolean,
    default: false
  },
  fromDate: {
    type: Date,
    default: Date.now
  },
  toDate: {
    type: Date,
    default: Date.now
  },
  showListPrice: {
    type: Boolean,
    default: false
  }
});

EventSchema.plugin(timestamps);

module.exports = mongoose.model("Event", EventSchema);
