const mongoose = require('mongoose');
const Schema = mongoose.Schema;

const ActionSchema = new Schema({
  actionType: {
    type: String,
    enum: ['page-ref', 'open-cart']
  },
  actionInfo: {
    type: Object
  }
});

const NotificationSchema = new Schema({
  receivers: [{
    type: mongoose.Schema.Types.ObjectId,
    ref: 'User'
  }],
  event: {
    type: mongoose.Schema.Types.ObjectId,
    ref: 'Event'
  },
  thumbnailType: {
    type: String,
    enum: ['Bid', 'Deal', 'Box', 'Negotiation']
  },
  header: String,
  message: String,
  readBy: {
    type: [{
      readerId: {
        type: mongoose.Schema.Types.ObjectId,
        ref: 'User'
      },
      readAt: {
        type: Date,
        default: Date.now
      },
    }],
    default: []
  },
  action: ActionSchema
}, {
  timestamps: true
});

module.exports = mongoose.model('Notification', NotificationSchema);