const mongoose = require('mongoose');
const Schema = mongoose.Schema;
const timestamps = require('mongoose-timestamps');

const SettingsSchema = new Schema({
  smsNotifications: {
    type: Boolean,
    default: true
  }
});

const UserSchema = new Schema({
  maxBoxTypes: Number,  
  boxTypes: [{
    type: Schema.ObjectId,
    ref: 'BoxType'
  }],
  email: {
    type: String,
    unique: true,
    lowercase: true,
    trim: true,
    required: true
  },
  adminToken: String,
  emailToken: String,
  password: {
    type: String,
    trim: true,
    required: true
  },
  firstName: {
    type: String,
    trim: true
  },
  lastName: {
    type: String,
    trim: true
  },
  displayName: {
    type: String,
    trim: true,
    required: true
  },
  address: {
    type: String,
    trim: true
  },
  city: {
    type: String,
    trim: true
  },
  country: {
    type: String,
    trim: true
  },
  phone: {
    type: String,
    trim: true
  },
  activated: {
    type: Boolean,
    default: false
  },
  resetToken: String,
  resetTokenExpiration: Date,
  status: {
    type: String,
    enum: ['pending', 'active', 'removed']
  },
  gender: {
    type: String,
    enum: ['male', 'female', 'other']
  },
  userType: {
    type: String,
    enum: ['buyer', 'supplier', 'admin']
  },
  isAdmin: Boolean,
  supplier: {
    type: Schema.ObjectId,
    ref: 'Supplier'
  },
  buyer: {
    type: Schema.ObjectId,
    ref: 'Buyer'
  },
  admin: {
    type: Schema.ObjectId,
    ref: 'Admin'
  },
  settings: {
    type: SettingsSchema,
    default: SettingsSchema
  }
});

UserSchema.plugin(timestamps);

module.exports = mongoose.model('User', UserSchema);
